import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, addDoc } from 'firebase/firestore';
import './ImportForm.css';

const ImportForm = () => {
  const navigate = useNavigate();
  const [formData, setFormData] = useState({
    title: '',
    type: 'Agent X',
    folderUrl: '',
    tagToDivide: '',
    htmlContent: ''
  });

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData(prevState => ({
      ...prevState,
      [name]: value
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      // Create new session in Firebase
      const sessionsRef = collection(db, 'sessions');
      const newSession = await addDoc(sessionsRef, {
        ...formData,
        timestamp: new Date().toISOString(),
        drafts: [{
          html: formData.htmlContent,
          timestamp: new Date().toISOString()
        }]
      });

      // Process SVGs and add section markers
      const processedHtml = processHtml(formData.htmlContent);
      
      // Update the session with processed HTML
      // TODO: Update session with processed HTML

      navigate('/current');
    } catch (error) {
      console.error('Error creating session:', error);
    }
  };

  const processHtml = (html) => {
    // TODO: Implement HTML processing logic
    // - Extract and save SVGs
    // - Add section markers
    return html;
  };

  return (
    <form className="import-form" onSubmit={handleSubmit}>
      <div className="form-group">
        <label htmlFor="title">Title:</label>
        <input
          type="text"
          id="title"
          name="title"
          value={formData.title}
          onChange={handleChange}
          required
        />
      </div>

      <div className="form-group">
        <label>Type:</label>
        <div className="radio-group">
          <label>
            <input
              type="radio"
              name="type"
              value="Agent X"
              checked={formData.type === 'Agent X'}
              onChange={handleChange}
            />
            Agent X
          </label>
          <label className="disabled">
            <input
              type="radio"
              name="type"
              value="Raw text"
              disabled
            />
            Raw text
          </label>
          <label className="disabled">
            <input
              type="radio"
              name="type"
              value="all HTML"
              disabled
            />
            all HTML
          </label>
        </div>
      </div>

      <div className="form-group">
        <label htmlFor="folderUrl">Folder URL:</label>
        <input
          type="text"
          id="folderUrl"
          name="folderUrl"
          value={formData.folderUrl}
          onChange={handleChange}
          placeholder="Optional - for future use"
        />
      </div>

      <div className="form-group">
        <label htmlFor="tagToDivide">Tag to divide:</label>
        <input
          type="text"
          id="tagToDivide"
          name="tagToDivide"
          value={formData.tagToDivide}
          onChange={handleChange}
          placeholder="Optional - for future use"
        />
      </div>

      <div className="form-group">
        <label htmlFor="htmlContent">HTML to import:</label>
        <textarea
          id="htmlContent"
          name="htmlContent"
          value={formData.htmlContent}
          onChange={handleChange}
          required
          rows="10"
        />
      </div>

      <button type="submit" className="import-button">Import</button>
    </form>
  );
};

export default ImportForm;

