import React, { useEffect, useRef } from 'react';
import './PreviewFrame.css';

const PreviewFrame = ({ html, onSectionClick }) => {
  const iframeRef = useRef(null);
  const scrollPositionRef = useRef(0);

  useEffect(() => {
    if (iframeRef.current) {
      // Store current scroll position
      const currentScroll = iframeRef.current.contentWindow.scrollY;
      scrollPositionRef.current = currentScroll;

      // Write HTML content
      const doc = iframeRef.current.contentDocument;
      doc.open();
      doc.write(html);
      doc.close();

      // Add click listener to sections
      const sections = doc.getElementsByTagName('section');
      Array.from(sections).forEach(section => {
        section.addEventListener('click', (e) => {
          e.preventDefault();
          // Find section boundaries
          let sectionId;
          for (let i = 1; i <= sections.length + 1; i++) {
            if (section.innerHTML.includes(`SECTION${String(i).padStart(2, '0')}`)) {
              sectionId = i;
              break;
            }
          }
          if (sectionId) {
            onSectionClick({
              id: `SECTION${String(sectionId).padStart(2, '0')}`,
              html: section.outerHTML
            });
          }
        });
      });

      // Restore scroll position
      iframeRef.current.contentWindow.scrollTo(0, scrollPositionRef.current);
    }
  }, [html, onSectionClick]);

  return (
    <div className="preview-frame">
      <iframe
        ref={iframeRef}
        title="HTML Preview"
        sandbox="allow-same-origin"
      />
    </div>
  );
};

export default PreviewFrame;

