import React from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { doc, updateDoc } from 'firebase/firestore';
import './SessionControls.css';

const SessionControls = ({ sessionId, html, sessionName }) => {
  const navigate = useNavigate();
  const [lastSaved, setLastSaved] = React.useState(null);

  const formatTimeAgo = (timestamp) => {
    if (!timestamp) return '';
    const minutes = Math.floor((Date.now() - timestamp) / 60000);
    if (minutes < 60) return `${minutes}m`;
    const hours = Math.floor(minutes / 60);
    if (hours < 24) return `${hours}hr${minutes % 60}m`;
    return `${Math.floor(hours / 24)}d`;
  };

  const saveSession = async (buildAndLeave = false) => {
    try {
      const sessionRef = doc(db, 'sessions', sessionId);
      const timestamp = Date.now();
      
      await updateDoc(sessionRef, {
        drafts: [{
          html,
          timestamp
        }]
      });

      setLastSaved(timestamp);

      if (buildAndLeave) {
        // Process HTML before leaving
        const processedHtml = processHtmlForExport(html);
        await updateDoc(sessionRef, {
          finalBuild: processedHtml
        });
        navigate('/sessions');
      }
    } catch (error) {
      console.error('Error saving session:', error);
    }
  };

  const processHtmlForExport = (html) => {
    // Remove section markers
    let processed = html.replace(/SECTION\d+/g, '');
    // TODO: Replace [SVG1], [SVG2] with actual SVGs
    return processed;
  };

  return (
    <div className="session-controls">
      <div className="session-info">
        <span className="session-name">{sessionName}</span>
      </div>
      
      <div className="save-time">
        {lastSaved && `Last saved ${formatTimeAgo(lastSaved)} ago`}
      </div>
      
      <div className="action-buttons">
        <button 
          className="save-btn"
          onClick={() => saveSession(false)}
        >
          Save
        </button>
        <button 
          className="build-leave-btn"
          onClick={() => saveSession(true)}
        >
          Save, Build & Leave
        </button>
      </div>
    </div>
  );
};

export default SessionControls;

