import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, addDoc } from 'firebase/firestore';
import ImportForm from '../components/ImportForm';
import './ImportPage.css';

const ImportPage = () => {
  const navigate = useNavigate();
  const [importing, setImporting] = useState(false);
  const [error, setError] = useState('');

  const processHtml = (html) => {
    let processedHtml = html;
    const svgs = [];
    let svgCount = 1;

    // Extract SVGs
    const svgRegex = /<svg[\s\S]*?<\/svg>/g;
    processedHtml = processedHtml.replace(svgRegex, (match) => {
      svgs.push(match);
      return `[SVG${svgCount++}]`;
    });

    // Add section markers
    const sectionRegex = /(<section[\s\S]*?<\/section>)/g;
    let sectionCount = 1;
    processedHtml = processedHtml.replace(sectionRegex, (match) => {
      const marker = `SECTION${String(sectionCount++).padStart(2, '0')}`;
      return `${marker}\n${match}`;
    });

    return { processedHtml, svgs };
  };

  const handleImport = async (formData) => {
    try {
      setImporting(true);
      setError('');

      const { processedHtml, svgs } = processHtml(formData.htmlContent);

      const sessionRef = await addDoc(collection(db, 'sessions'), {
        title: formData.title,
        type: formData.type,
        folderUrl: formData.folderUrl,
        tagToDivide: formData.tagToDivide,
        timestamp: new Date().toISOString(),
        svgs: svgs,
        drafts: [{
          html: processedHtml,
          timestamp: new Date().toISOString()
        }]
      });

      navigate('/current', { state: { sessionId: sessionRef.id } });
    } catch (err) {
      console.error('Import error:', err);
      setError('Failed to import HTML: ' + err.message);
    } finally {
      setImporting(false);
    }
  };

  return (
    <div className="import-page">
      <h1>Import HTML</h1>
      {error && <div className="error-message">{error}</div>}
      <ImportForm 
        onSubmit={handleImport}
        isSubmitting={importing}
      />
    </div>
  );
};

export default ImportPage;

